Actions, Resources, and Condition Keys for AWS CodeBuild - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeBuild.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS CodeBuild

AWS CodeBuild (service prefix: `codebuild`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS CodeBuild
- Resources Defined by AWS CodeBuild
- Condition Keys for AWS CodeBuild

## Actions Defined by AWS CodeBuild

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchDeleteBuilds | Deletes one or more builds. | Write | project* |  |
BatchGetBuilds | Gets information about one or more builds. | Read | project* |  |
BatchGetProjects | Gets information about one or more build projects. | Read | project* |  |
CreateProject | Creates a build project. | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWebhook | For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository. | Write | project* |  |
DeleteOAuthToken [permission only] | Deletes an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console. | Write |  |  |
DeleteProject | Deletes a build project. | Write | project* |  |
DeleteSourceCredentials | Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials. | Write |  |  |
DeleteWebhook | For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository. | Write | project* |  |
ImportSourceCredentials | Imports the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository. | Write |  |  |
InvalidateProjectCache | Resets the cache for a project. | Write | project* |  |
ListBuilds | Gets a list of build IDs, with each build ID representing a single build. | List |  |  |
ListBuildsForProject | Gets a list of build IDs for the specified build project, with each build ID representing a single build. | List | project* |  |
ListConnectedOAuthAccounts [permission only] | Lists connected third-party OAuth providers. Only used in the AWS CodeBuild console. | List |  |  |
ListCuratedEnvironmentImages | Gets information about Docker images that are managed by AWS CodeBuild. | List |  |  |
ListProjects | Gets a list of build project names, with each build project name representing a single build project. | List |  |  |
ListRepositories [permission only] | Lists source code repositories from a connected third-party OAuth provider. Only used in the AWS CodeBuild console. | List |  |  |
ListSourceCredentials | Returns a list of SourceCredentialsInfo objects. | List |  |  |
PersistOAuthToken [permission only] | Saves an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console. | Write |  |  |
StartBuild | Starts running a build. | Write | project* |  |
StopBuild | Attempts to stop running a build. | Write | project* |  |
UpdateProject | Changes the settings of an existing build project. | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateWebhook | Updates the webhook associated with an AWS CodeBuild build project. | Write | project* |  |

## Resources Defined by AWS CodeBuild

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
build | `arn:${Partition}:codebuild:${Region}:${Account}:build/${BuildId}` |
project | `arn:${Partition}:codebuild:${Region}:${Account}:project/${ProjectName}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS CodeBuild

AWS CodeBuild defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

On this page:

- Actions Defined by AWS CodeBuild
- Resources Defined by AWS CodeBuild
- Condition Keys for AWS CodeBuild

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more